@@ -14,8 +14,11 @@ use overload '""' => \&rgb;
 
 use Carp;
 use UUID::Tiny ':std';
+use Scalar::Util qw(weaken);
 
-our $VERSION = v0.09;
+our $VERSION = v0.10;
+
+use parent 'Data::URIID::Base';
 
 
 
@@ -27,6 +30,8 @@ sub new {
     $opts{rgb} = uc($opts{rgb});
     $opts{rgb} =~ /^#[0-9A-F]{6}$/ or die 'Bad format';
 
+    weaken($opts{extractor});
+
     return bless \%opts, $pkg;
 }
 
@@ -36,23 +41,29 @@ sub rgb {
     return $self->{rgb} // croak 'No RGB value';
 }
 
+# --- Overrides for Data::URIID::Base ---
 
 sub ise {
-    my ($self) = @_;
+    my ($self, %opts) = @_;
 
-    if (defined $self->{ise}) {
-        return $self->{ise};
-    } else {
+    unless (defined $self->{ise}) {
         my $req = lc($self->rgb);
 
         $req = sprintf('#%s%s%s', $1 x 6, $2 x 6, $3 x 6) if $req =~ /^#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})$/;
 
         if ($req =~ /^#[a-f0-9]{36}$/) {
-            return $self->{ise} = create_uuid_as_string(UUID_SHA1, '88d3944f-a13b-4e35-89eb-e3c1fbe53e76', $req);
+            $self->{ise} = create_uuid_as_string(UUID_SHA1, '88d3944f-a13b-4e35-89eb-e3c1fbe53e76', $req);
         } else {
             croak 'Bad format for colour';
         }
     }
+
+    return $self->SUPER::ise(%opts);
+}
+
+sub displayname {
+    my ($self, %opts) = @_;
+    return $self->SUPER::displayname(%opts, _fallback => $self->rgb);
 }
 
 1;
@@ -69,7 +80,7 @@ Data::URIID::Colour - Extractor for identifiers from URIs
 
 =head1 VERSION
 
-version v0.09
+version v0.10
 
 =head1 SYNOPSIS
 
@@ -77,6 +88,10 @@ version v0.09
 
     my $colour = Data::URIID::Colour->new(rgb => '#FF0000');
 
+This module represents a single colour.
+
+This package inherits from L<Data::URIID::Base>.
+
 =head1 METHODS
 
 =head2 new
@@ -92,6 +107,10 @@ The following options are defined:
 
 The RGB value in hex notation. E.g. C<#FF0000>.
 
+=item C<extractor>
+
+optionally, an instance of L<Data::URIID>.
+
 =back
 
 =head2 rgb
@@ -101,12 +120,6 @@ The RGB value in hex notation. E.g. C<#FF0000>.
 Returns the colour in six digit hex notation with prepended pound (C<#>) if successful or C<die> otherwise.
 The returned value is suitable for use in CSS.
 
-=head2 ise
-
-    my $ise = $colour->ise;
-
-This method will return the ISE of the colour if successful or C<die> otherwise.
-
 =head1 AUTHOR
 
 Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
